aboutsummaryrefslogtreecommitdiffstats
path: root/includes/content
diff options
context:
space:
mode:
Diffstat (limited to 'includes/content')
-rw-r--r--includes/content/Hook/ContentHandlerForModelIDHook.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/includes/content/Hook/ContentHandlerForModelIDHook.php b/includes/content/Hook/ContentHandlerForModelIDHook.php
index 9cb81717437f..c05394d6202a 100644
--- a/includes/content/Hook/ContentHandlerForModelIDHook.php
+++ b/includes/content/Hook/ContentHandlerForModelIDHook.php
@@ -19,9 +19,9 @@ interface ContentHandlerForModelIDHook {
*
* @since 1.35
*
* @param string $modeName Requested content model name
* @param ContentHandler &$handler Set this to a ContentHandler object, if desired
* @return bool|void True or no return value to continue or false to abort
*/
- public function onContentHandlerForModelID( $modeName, &$handler );
+ public function onContentHandlerForModelID( $modelName, &$handler );
}
@@ -19,9 +19,9 @@ interface ContentHandlerForModelIDHook {
* @since 1.35
*
- * @param string $modeName Requested content model name
+ * @param string $modelName Requested content model name
* @param ContentHandler &$handler Set this to a ContentHandler object, if desired
* @return bool|void True or no return value to continue or false to abort